import { select } from 'd3';
import { viz } from './viz';
import { data } from '@ayush-shinde/ev_data';

export const main = (container) => {
  const resize = () => {
    const width = container.clientWidth;
    const height = container.clientHeight;

    const svg = select(container)
      .selectAll('svg')
      .data([null])
      .join('svg')
      .attr('width', width)
      .attr('height', height);

    viz(svg, {
      data,
      xValue: (d) => d.Range,
      xAxisLabelText: 'Driving Range (kms)',
      xAxisLabelOffset: 20,
      yValue: (d) => d.Price,
      yAxisLabelText: 'Price (Euros)',
      yAxisLabelOffset: 17,
      innerRectFill: '#E8E8E8',
      circleRadius: 125 / 20,
      circleOpacity: 600 / 1000,
      marginTop: 20,
      marginBottom: 55,
      marginLeft: 80,
      marginRight: 20,
      width,
      height,
    });
  };

  resize();

  window.addEventListener('resize', resize);
};

// Sample row (d):
//   {
//   "Battery": 75,
//   "Car_name": "Tesla Model Y Long Range Dual Motor",
//   "Car_name_link": "https://ev-database.org/car/1619/Tesla-Model-Y-Long-Range-Dual-Motor",
//   "Efficiency": 172,
//   "Fast_charge": 670,
//   "Price_DE": 59017,
//   "Range": 435,
//   "Top_speed": 217,
//   "acceleration": 5
//   }
